@@ -1,8 +1,9 @@
-"""auxjad
+"""
+Auxjad
 ======
 
-``auxjad`` is a library of auxiliary functions and classes for Abjad 3.1 aimed
-at composers of algorithmic music. All classes and functions have a __doc__
+Auxjad is a library of auxiliary classes and functions for Abjad 3.1 aimed at
+composers of algorithmic music. All classes and functions have a ``__doc__``
 attribute with usage instructions.
 
 Documentation is available at https://gilbertohasnofb.github.io/auxjad-docs/.
@@ -12,20 +13,21 @@ Bugs can be reported through the project's Issue Tracker.
 This library is published under the MIT License.
 """
 
-from .core.Adrifter import Adrifter
 from .core.CartographySelector import CartographySelector
+from .core.Drifter import Drifter
 from .core.Fader import Fader
 from .core.Hocketer import Hocketer
 from .core.LeafDynMaker import LeafDynMaker
-from .core.LoopByList import LoopByList
-from .core.LoopByNotes import LoopByNotes
-from .core.LoopByWindow import LoopByWindow
+from .core.LeafLooper import LeafLooper
+from .core.ListLooper import ListLooper
 from .core.Phaser import Phaser
+from .core.PitchRandomiser import PitchRandomiser
 from .core.Shuffler import Shuffler
 from .core.TenneySelector import TenneySelector
+from .core.WindowLooper import WindowLooper
 
-from .entities.ArtificialHarmonic import ArtificialHarmonic
-from .entities.HarmonicNote import HarmonicNote
+from .score.ArtificialHarmonic import ArtificialHarmonic
+from .score.HarmonicNote import HarmonicNote
 
 from .utilities.close_container import close_container
 from .utilities.container_is_full import container_is_full
@@ -42,6 +44,7 @@ from .utilities.remove_repeated_time_signatures import (
 from .utilities.repeat_container import repeat_container
 from .utilities.reposition_clefs import reposition_clefs
 from .utilities.reposition_dynamics import reposition_dynamics
+from .utilities.reposition_slurs import reposition_slurs
 from .utilities.respell_container import respell_container
 from .utilities.respell_chord import respell_chord
 from .utilities.rests_to_multimeasure_rest import rests_to_multimeasure_rest
@@ -54,21 +57,22 @@ from .utilities.underfull_duration import underfull_duration
 
 
 __author__ = "Gilberto Agostinho <gilbertohasnofb@gmail.com>"
-__version__ = "0.8.0"
+__version__ = "0.8.6"
 __all__ = [
     '__author__',
     '__version__',
-    'Adrifter',
     'CartographySelector',
+    'Drifter',
     'Fader',
     'Hocketer',
     'LeafDynMaker',
-    'LoopByList',
-    'LoopByNotes',
-    'LoopByWindow',
+    'LeafLooper',
+    'ListLooper',
     'Phaser',
+    'PitchRandomiser',
     'Shuffler',
     'TenneySelector',
+    'WindowLooper',
     'ArtificialHarmonic',
     'HarmonicNote',
     'close_container',
@@ -84,6 +88,7 @@ __all__ = [
     'repeat_container',
     'reposition_clefs',
     'reposition_dynamics',
+    'reposition_slurs',
     'respell_container',
     'respell_chord',
     'rests_to_multimeasure_rest',
