@@ -7,49 +7,42 @@ class CartographySelector():
     weighted function constructed with a fixed decay rate. The decay rate
     represents the ratio of probabilities of any index given the probability of
     the preceeding one. For instance, if the decay rate is set to ``0.75``
-    (which is its default value), the probability of the element in index 1 of
-    the input list being selected is 75% the probability of the element in
-    index 0, and the probability of the element in index 2 is 56.25% (0.75^2)
-    the probability of the element in index 0. This is the selector used in my
-    *Cartography* series of compositions.
+    (which is its default value), the probability of the element in index ``1``
+    of the input :obj:`list` being selected is :math:`75\%`` the probability of
+    the element in index ``0``, and the probability of the element in index
+    ``2`` is :math:`56.25\%`` (i.e. :math:`0.75^2`) the probability of the
+    element in index ``0``. The probability :math:`P(n)`` of the :math:`n`-th
+    element can thus be expressed as a relation to the probability of another
+    element :math:`k` indexes apart using:
 
-    Example:
-        The selector should be initialised with a list of objects. The elements
-        of this list can be of any type.
+    .. math::
+
+        P(n) = (3/4)^k \times P(n-k)
+
+    This is the selector used in my *Cartography* series of compositions.
+
+    Basic usage:
+        The selector should be initialised with a :obj:`list` of objects. The
+        elements of this :obj:`list` can be of any type.
 
         >>> selector = auxjad.CartographySelector([0, 1, 2, 3, 4])
         >>> selector.contents
         [0, 1, 2, 3, 4]
 
-        The default decay rate is 0.75; that is, the weight of any given
-        elements is the weight of the previous one multiplied by 0.75. The
-        weights are associated with the index position, not the elements
-        themselves.
-
-        >>> selector.weights
-        [1.0, 0.75, 0.5625, 0.421875, 0.31640625]
-
-        Applying the ``len()`` function to the selector will return the length
-        of the input list.
-
-        >>> len(selector)
-        5
-
         Calling the selector will output one of its elements, selected
         according to its weight function.
 
         >>> selector()
         2
 
-        Alternatively, use the ``next()`` function or ``__next__()`` method to
-        get the next result.
+        The default decay rate is ``0.75``; that is, the weight of any given
+        elements is the weight of the previous one multiplied by ``0.75``. The
+        :attr:`weights` are associated with the index position, not the
+        elements themselves.
 
-        >>> selector.__next__()
-        1
-        >>> next(selector)
-        0
+        >>> selector.weights
+        [1.0, 0.75, 0.5625, 0.421875, 0.31640625]
 
-    Example:
         By default, only the weight function (defined by the decay rate) is
         taken into consideration when selecting an element. This means that
         repeated elements can appear, as shown below.
@@ -60,6 +53,25 @@ class CartographySelector():
         >>> result
         203001402200011111101400310140
 
+    :func:`len()` function:
+        Applying the :func:`len()` function to the selector will return the
+        length of the input :obj:`list`.
+
+        >>> selector = auxjad.CartographySelector([0, 1, 2, 3, 4])
+        >>> len(selector)
+        5
+
+    :func:`next()` function:
+        Alternatively, use the :func:`next()` function or :meth:`__next__()`
+        method to get the next result.
+
+        >>> selector = auxjad.CartographySelector([0, 1, 2, 3, 4])
+        >>> selector.__next__()
+        1
+        >>> next(selector)
+        0
+
+    ``no_repeat``:
         Calling the selector with the optional keyword argument ``no_repeat``
         set to ``True`` will forbid immediate repetitions among consecutive
         calls.
@@ -71,8 +83,8 @@ class CartographySelector():
         >>> result
         210421021020304024230120241202
 
-    Example:
-        The keyword argument ``decay_rate`` can be used to set a different
+    :attr:`decay_rate`:
+        The keyword argument :attr:`decay_rate` can be used to set a different
         decay rate when creating a selector.
 
         >>> selector = auxjad.CartographySelector([0, 1, 2, 3, 4],
@@ -82,7 +94,7 @@ class CartographySelector():
         [1.0, 0.5, 0.25, 0.125, 0.0625]
 
         The decay rate can also be set after the creation of a selector using,
-        the property ``decay_rate``.
+        the property :attr:`decay_rate`.
 
         >>> selector = auxjad.CartographySelector([0, 1, 2, 3, 4])
         >>> selector.decay_rate = 0.2
@@ -95,10 +107,10 @@ class CartographySelector():
         >>> result
         '000001002100000201001030000100'
 
-    Example:
+    :meth:`append`:
         Appending is a type of content transformation. It discards the first
-        element of the selector's ``contents``, shifts all others leftwards,
-        and then appends the new element to the last index.
+        element of the selector's :attr:`contents`, shifts all others
+        leftwards, and then appends the new element to the last index.
 
         >>> selector = auxjad.CartographySelector([0, 1, 2, 3, 4])
         >>> selector.contents
@@ -110,11 +122,12 @@ class CartographySelector():
         >>> selector.contents
         [2, 3, 4, 5, 42]
 
-    Example:
-        The method ``append_keeping_n()`` is similar to ``append()``, but it
-        keeps the first ``n`` elements of ``contents`` untouched. It thus
-        discards the n+1-th element, shifts all the next elements one position
-        lefwards, and finally appends the new element at the last index.
+    :meth:`append_keeping_n`:
+        The method :meth:`append_keeping_n` is similar to :meth:`append`, but
+        it keeps the first ``n`` elements of :attr:`contents` untouched. It
+        thus discards the :math:`n+1`-th element, shifts all the next elements
+        one position lefwards, and finally appends the new element at the last
+        index.
 
         >>> selector = auxjad.CartographySelector([10, 7, 14, 31, 98])
         >>> selector.contents
@@ -123,9 +136,9 @@ class CartographySelector():
         >>> selector.contents
         [10, 7, 31, 98, 100]
 
-    Example:
+    :meth:`prepend`:
         Prepending is another type of content transformation. It discards the
-        last element of the ``contents``, shifts all others rightwards, and
+        last element of :attr:`contents`, shifts all others rightwards, and
         then prepends the new element to the first index.
 
         >>> selector = auxjad.CartographySelector([0, 1, 2, 3, 4])
@@ -138,7 +151,7 @@ class CartographySelector():
         >>> selector.contents
         [71, -1, 0, 1, 2]
 
-    Example:
+    :meth:`rotate`:
         Rotation is another type of content transformation. It rotates all
         elements rightwards, moving the last element to the first index. If the
         optional keyword argument ``anticlockwise`` is set to ``True``, the
@@ -157,12 +170,12 @@ class CartographySelector():
         >>> selector.contents
         [1, 2, 3, 4, 0]
 
-    Example:
+    :meth:`mirror`:
         The mirror transformation swaps the element of the input index with its
         complementary element. Complementary elements are defined as the pair
         of elements which share the same distance from the centre of the
-        ``contents`` (in terms of number of indeces), and are located at either
-        side.
+        :attr:`contents` (in terms of number of indeces), and are located at
+        either side.
 
         >>> selector = auxjad.CartographySelector([0, 1, 2, 3, 4])
         >>> selector.contents
@@ -180,9 +193,9 @@ class CartographySelector():
         >>> selector.contents
         [0, 3, 2, 1, 4]
 
-    Example:
+    :meth:`mirror_random`:
         To mirror a random pair of complementary elements, use the
-        ``mirror_random()`` method. In case of a selector with an odd number
+        :meth:`mirror_random` method. In case of a selector with an odd number
         of elements, this method will never pick an element at the pivot point
         since the operation would not change the contents.
 
@@ -199,9 +212,9 @@ class CartographySelector():
         >>> selector.contents
         [4, 1, 2, 3, 0]
 
-    Example:
-        The method ``shuffle()`` will shuffle the position of the elements of
-        the selector's ``contents``.
+    :meth:`shuffle`:
+        The method :meth:`shuffle` will shuffle the position of the elements of
+        the selector's :attr:`contents`.
 
         >>> selector = auxjad.CartographySelector([0, 1, 2, 3, 4])
         >>> selector.contents
@@ -210,9 +223,9 @@ class CartographySelector():
         >>> selector.contents
         [1, 4, 3, 0, 2]
 
-    Example:
+    :attr:`contents`:
         The contents of a selector can also be altered after it has been
-        initialised using the ``contents`` property. The length of the
+        initialised using the :attr:`contents` property. The length of the
         contents can change as well.
 
         >>> selector = auxjad.CartographySelector([0, 1, 2, 3, 4],
@@ -230,9 +243,9 @@ class CartographySelector():
         >>> selector.weights
         [1.0, 0.5, 0.25, 0.125, 0.0625, 0.03125, 0.015625]
 
-    Example:
-        Use the read-only properties ``previous_result`` and ``previous_index``
-        to output the previous result and its index.
+    :attr:`previous_result` and :attr:`previous_index`:
+        Use the read-only properties :attr:`previous_result` and
+        :attr:`previous_index` to output the previous result and its index.
 
         >>> selector = auxjad.CartographySelector([10, 7, 14, 31, 98])
         >>> selector()
@@ -243,9 +256,9 @@ class CartographySelector():
         >>> selector.previous_result
         14
 
-    Example:
-        The ``contents`` of instances of this class can be indexed and sliced.
-        This allows reading, assigning, or deleting values from ``contents``.
+    Slicing and indexing:
+        Instances of this class can be indexed and sliced. This allows reading,
+        assigning, or deleting values from :attr:`contents`.
 
         >>> selector = auxjad.CartographySelector([10, 7, 14, 31, 98])
         >>> selector[1]
@@ -302,18 +315,20 @@ class CartographySelector():
     ### SPECIAL METHODS ###
 
     def __repr__(self) -> str:
-        r'Returns interpret representation of ``contents``.'
+        r'Returns interpreter representation of :attr:`contents`.'
         return str(self._contents)
 
     def __len__(self) -> int:
-        r'Returns the length of ``contents``.'
+        r'Returns the length of :attr:`contents`.'
         return len(self._contents)
 
     def __call__(self,
                  *,
                  no_repeat: bool = False,
-                 ):
-        r'Calls the selection process and outputs one element of ``contents``.'
+                 ) -> Any:
+        r"""Calls the selection process and outputs one element of
+        :attr:`contents`.
+        """
         if not isinstance(no_repeat, bool):
             raise TypeError("'no_repeat' must be 'bool")
         if not no_repeat:
@@ -331,28 +346,27 @@ class CartographySelector():
         self._previous_index = new_index
         return self._contents[self._previous_index]
 
-    def __next__(self,
-                 *,
-                 no_repeat: bool = False,
-                 ):
-        r'Calls the selection process and outputs one element of ``contents``.'
-        return self.__call__(no_repeat=no_repeat)
+    def __next__(self) -> Any:
+        r"""Calls the selection process and outputs one element of
+        :attr:`contents`.
+        """
+        return self.__call__()
 
-    def __getitem__(self, key: int):
-        r"""Returns one or more elements of ``contents`` through indexing or
-        slicing.
+    def __getitem__(self, key: int) -> Any:
+        r"""Returns one or more elements of :attr:`contents` through indexing
+        or slicing.
         """
         return self._contents[key]
 
     def __setitem__(self, key, value):
-        r"""Assigns values to one or more elements of ``contents`` through
+        r"""Assigns values to one or more elements of :attr:`contents` through
         indexing or slicing.
         """
         self._contents[key] = value
 
     def __delitem__(self, key):
-        r"""Deletes one or more elements of ``contents`` through indexing or
-        slicing.
+        r"""Deletes one or more elements of :attr:`contents` through indexing
+        or slicing.
         """
         del self._contents[key]
         self._generate_weights()
@@ -361,16 +375,17 @@ class CartographySelector():
 
     def append(self, new_element):
         r"""A type of content transformation, it discards the first element of
-        the ``contents``, shifts all others leftwards, and then appends the new
-        element to the last index.
+        the :attr:`contents`, shifts all others leftwards, and then appends the
+        new element to the last index.
         """
         self._contents = self._contents[1:] + [new_element]
 
     def append_keeping_n(self, new_element, n: int):
-        r"""A type of content transformation similar to ``append()``, it keeps
-        the first ``n`` elements of ``contents`` untouched, it then discards
-        the n+1-th element, shifts all the next elements one position lefwards,
-        and finally appends the new element at the last index.
+        r"""A type of content transformation similar to :meth:`append`, it
+        keeps the first ``n`` elements of :attr:`contents` untouched, it then
+        discards the :math:`n+1`-th element, shifts all the next elements one
+        position lefwards, and finally appends the new element at the last
+        index.
         """
         self._contents = (self._contents[:n]
                           + self._contents[n + 1:]
@@ -378,8 +393,8 @@ class CartographySelector():
 
     def prepend(self, new_element):
         r"""A type of content transformation, it discards the last element of
-        the ``contents``, shifts all others rightwards, and then prepends the
-        new element to the first index.
+        the :attr:`contents`, shifts all others rightwards, and then prepends
+        the new element to the first index.
         """
         self._contents = [new_element] + self._contents[:-1]
 
@@ -398,7 +413,7 @@ class CartographySelector():
         r"""A type of content transformation which swaps the element of the
         input index with its complementary element. Complementary elements are
         defined as the pair of elements which share the same distance from the
-        centre of the ``contents`` (in terms of number of indeces), and are
+        centre of the :attr:`contents` (in terms of number of indeces), and are
         located at either side.
         """
         aux = self._contents[index]
@@ -409,21 +424,21 @@ class CartographySelector():
         r"""A type of content transformation which swaps the element of a
         random index with its complementary element. Complementary elements are
         defined as the pair of elements which share the same distance from the
-        centre of the ``contents`` (in terms of number of indeces), and are
+        centre of the :attr:`contents` (in terms of number of indeces), and are
         located at either side.
         """
         max_index = self.__len__() // 2 - 1
         self.mirror(random.randint(0, max_index))
 
     def shuffle(self):
-        r'Shuffles the position of the elements of ``contents``.'
+        r'Shuffles the position of the elements of :attr:`contents`.'
         random.shuffle(self._contents)
 
     ### PRIVATE METHODS ###
 
     def _generate_weights(self):
-        r"""Given a decay rate, this method generates the weights of individual
-        indeces.
+        r"""Given a decay rate, this method generates the :attr:`weights` of
+        individual indeces.
         """
         self._weights = []
         for n in range(self.__len__()):
@@ -433,12 +448,12 @@ class CartographySelector():
 
     @property
     def contents(self) -> list:
-        r'The ``list`` from which the selector picks elements.'
+        r'The :obj:`list` from which the selector picks elements.'
         return self._contents
 
     @contents.setter
     def contents(self,
-                 contents: list
+                 contents: list,
                  ):
         if not isinstance(contents, list):
             raise TypeError("'contents' must be 'list")
@@ -450,10 +465,10 @@ class CartographySelector():
         r"""The decay rate represents the ratio of probabilities of any index
         given the probability of the preceeding one. For instance, if the decay
         rate is set to ``0.75`` (which is its default value), the probability
-        of the element in index 1 of the input list being selected is 0.75 the
-        probability of the element in index 0, and the probability of the
-        element in index 2 is 0.5625 (0.75^2) the probability of the element in
-        index 0.
+        of the element in index ``1`` of the input :obj:`list` being selected
+        is ``0.75`` the probability of the element in index ``0``, and the
+        probability of the element in index ``2`` is ``0.5625`` (i.e. ``0.75``
+        squared) the probability of the element in index ``0``.
         """
         return self._decay_rate
 
