@@ -4,14 +4,15 @@ from .underfull_duration import underfull_duration
 
 
 def container_is_full(container: abjad.Container) -> bool:
-    r"""Returns a ``bool`` representing whether the last bar of an input
-    container (of type ``abjad.Container`` or child class) is fully filled in
+    r"""Returns a :obj:`bool` representing whether the last measure of an input
+    container (of type |abjad.Container| or child class) is fully filled in
     or not.
 
-    Example:
-        Returns ``True`` if the last bar of any container (or child class) is
-        full, otherwise returns ``False``. If no time signature is encountered,
-        it uses LilyPond's convention and considers the container as in 4/4.
+    Basic usage:
+        Returns ``True`` if the last measure of any container (or child class)
+        is full, otherwise returns ``False``. If no time signature is
+        encountered, it uses LilyPond's convention and considers the container
+        as in 4/4.
 
         >>> container1 = abjad.Container(r"c'4 d'4 e'4 f'4")
         >>> container2 = abjad.Container(r"c'4 d'4 e'4")
@@ -26,7 +27,7 @@ def container_is_full(container: abjad.Container) -> bool:
         >>> auxjad.container_is_full(container4)
         True
 
-    Example:
+    Time signature changes:
         Handles any time signatures as well as changes of time signature.
 
         >>> container1 = abjad.Container(r"\time 4/4 c'4 d'4 e'4 f'4")
@@ -42,7 +43,7 @@ def container_is_full(container: abjad.Container) -> bool:
         >>> auxjad.container_is_full(container4)
         False
 
-    Example:
+    Partial time signatures:
         Correctly handles partial time signatures.
 
         >>> container = abjad.Container(r"c'4 d'4 e'4 f'4")
@@ -51,7 +52,7 @@ def container_is_full(container: abjad.Container) -> bool:
         >>> auxjad.container_is_full(container)
         True
 
-    Example:
+    Multi-measure rests:
         It also handles multi-measure rests.
 
         >>> container1 = abjad.Container(r"R1")
@@ -69,14 +70,24 @@ def container_is_full(container: abjad.Container) -> bool:
 
     ..  error::
 
-        If a container is malformed, i.e. it has an underfilled bar before a
-        time signature change, the function raises a ``ValueError`` exception.
+        If a container is malformed, i.e. it has an underfilled measure before
+        a time signature change, the function raises a :exc:`ValueError`
+        exception.
 
         >>> container = abjad.Container(r"\time 5/4 g''1 \time 4/4 f'1")
         >>> auxjad.container_is_full(container)
-        ValueError: 'container' is malformed, with an underfull bar preceeding
-        a time signature change
+        ValueError: 'container' is malformed, with an underfull measure
+        preceeding a time signature change
+
+    ..  warning::
+
+        The input container must be a contiguous logical voice. When dealing
+        with a container with multiple subcontainers (e.g. a score containings
+        multiple staves), the best approach is to cycle through these
+        subcontainers, applying this function to them individually.
     """
     if not isinstance(container, abjad.Container):
         raise TypeError("argument must be 'abjad.Container' or child class")
+    if not abjad.select(container).leaves().are_contiguous_logical_voice():
+        raise ValueError("argument must be contiguous logical voice")
     return underfull_duration(container) == abjad.Duration(0)
