@@ -6,11 +6,11 @@ def remove_repeated_dynamics(container: abjad.Container,
                              ignore_hairpins: bool = False,
                              reset_after_rests: bool = False,
                              ):
-    r"""Mutates an input container (of type ``abjad.Container`` or child class)
+    r"""Mutates an input container (of type |abjad.Container| or child class)
     in place and has no return value; this function removes all consecutive
     repeated dynamic markings.
 
-    Example:
+    Basic usage:
         When two consecutive leaves have identical dynamics, the second
         one is removed:
 
@@ -46,7 +46,7 @@ def remove_repeated_dynamics(container: abjad.Container,
 
         .. figure:: ../_images/image-remove_repeated_dynamics-2.png
 
-    Example:
+    Dynamic structure:
         The function also removes dynamics that are separated by an arbitrary
         number of leaves without dynamics:
 
@@ -84,7 +84,7 @@ def remove_repeated_dynamics(container: abjad.Container,
 
         .. figure:: ../_images/image-remove_repeated_dynamics-4.png
 
-    Example:
+    Subcontainers:
         The input container can also handle subcontainers:
 
         >>> staff = abjad.Staff([abjad.Note("c'2"),
@@ -127,7 +127,7 @@ def remove_repeated_dynamics(container: abjad.Container,
 
         .. figure:: ../_images/image-remove_repeated_dynamics-6.png
 
-    Example:
+    ``ignore_hairpins``:
         By default, repeated dynamics with hairpins in between are not removed,
         but consecutive ones will.
 
@@ -211,7 +211,7 @@ def remove_repeated_dynamics(container: abjad.Container,
 
         .. figure:: ../_images/image-remove_repeated_dynamics-10.png
 
-    Example:
+    ``reset_after_rests``:
         By default, rests are treated just like any other leaf and thus notes
         with an identical dynamic separated by an arbitrary number of rests
         will be considered as repeated and the second dynamic will be removed.
@@ -246,15 +246,15 @@ def remove_repeated_dynamics(container: abjad.Container,
 
         .. figure:: ../_images/image-remove_repeated_dynamics-12.png
 
-    Example:
-        The argument ``reset_after_rests`` takes not only boolean values but
-        also duration (``abjad.Duration``, tuple, float, etc.). This sets the
-        maximum length of rests before which identical dynamics are restated.
-        If the total length of rests falls below that value, then repeated
-        dynamics are removed.
+    ``reset_after_rests`` and non-:obj:`bool` values:
+        The argument ``reset_after_rests`` takes not only :obj:`bool` values
+        but also durations (|abjad.Duration|, :obj:`tuple`, :obj:`float`,
+        etc.). This sets the maximum length of rests before which identical
+        dynamics are restated. If the total length of rests falls below that
+        value, then repeated dynamics are removed.
 
         In the case below, a rest of ``r2``. is shorter than a duration of
-        (4, 4), so the repeated dynamic is removed.
+        ``(4, 4)``, so the repeated dynamic is removed.
 
         >>> staff = abjad.Staff(r"c'4\pp r2. | c'1\pp")
         >>> auxjad.remove_repeated_dynamics(staff, reset_after_rests=(4, 4))
@@ -269,7 +269,7 @@ def remove_repeated_dynamics(container: abjad.Container,
 
         .. figure:: ../_images/image-remove_repeated_dynamics-13.png
 
-        But setting the duration to 2/4 forces the dynamic to be restated.
+        But setting the duration to ``2/4`` forces the dynamic to be restated.
 
         >>> staff = abjad.Staff(r"c'4\pp r2. | c'1\pp")
         >>> auxjad.remove_repeated_dynamics(staff, reset_after_rests=2 / 4)
@@ -285,7 +285,7 @@ def remove_repeated_dynamics(container: abjad.Container,
 
         .. figure:: ../_images/image-remove_repeated_dynamics-14.png
 
-    Example:
+    ``reset_after_rests``:
         The function also handles measure rests with ``reset_after_rests``.
 
         >>> staff = abjad.Staff(r"c'4\pp r2. | c'4\pp r2. | R1 | c'1\pp")
@@ -307,9 +307,18 @@ def remove_repeated_dynamics(container: abjad.Container,
         }
 
         .. figure:: ../_images/image-remove_repeated_dynamics-15.png
+
+    ..  warning::
+
+        The input container must be a contiguous logical voice. When dealing
+        with a container with multiple subcontainers (e.g. a score containings
+        multiple staves), the best approach is to cycle through these
+        subcontainers, applying this function to them individually.
     """
     if not isinstance(container, abjad.Container):
         raise TypeError("argument must be 'abjad.Container' or child class")
+    if not abjad.select(container).leaves().are_contiguous_logical_voice():
+        raise ValueError("argument must be contiguous logical voice")
     if not isinstance(ignore_hairpins, bool):
         raise TypeError("'ignore_hairpins' must be 'bool'")
     if not isinstance(reset_after_rests,
