@@ -11,13 +11,13 @@ def sync_containers(*containers: abjad.Container,
                     use_multimeasure_rests: bool = True,
                     adjust_last_time_signature: bool = True,
                     ):
-    r"""Mutates two or more input containers (of type ``abjad.Container`` or
+    r"""Mutates two or more input containers (of type |abjad.Container| or
     child class) in place and has no return value; this function finds the
     longest container among the inputs and adds rests to all the shorter ones,
     making them the same length. By default, it rewrites the last time
     signature if necessary, and uses multi-measure rests whenever possible.
 
-    Example:
+    Basic usage:
         Input two or more containers. This function will fill the shortest ones
         with rests ensuring all their lengths become the same.
 
@@ -45,8 +45,8 @@ def sync_containers(*containers: abjad.Container,
 
         Notice that the time signatures in the output are commented out with
         ``%%%``. This is because Abjad only applies time signatures to
-        containers that belong to a ``abjad.Staff``. The present function works
-        with either ``abjad.Container`` and ``abjad.Staff``.
+        containers that belong to a |abjad.Staff|. The present function works
+        with either |abjad.Container| and |abjad.Staff|.
 
         >>> container1 = abjad.Container(r"\time 4/4 g'2.")
         >>> container2 = abjad.Container(r"\time 4/4 c'1")
@@ -57,6 +57,9 @@ def sync_containers(*containers: abjad.Container,
             g'2.
             r4
         }
+
+        .. figure:: ../_images/image-close_container-3.png
+
         >>> staff = abjad.Staff([container1])
         >>> abjad.f(container1)
         {
@@ -65,7 +68,9 @@ def sync_containers(*containers: abjad.Container,
             r4
         }
 
-    Example:
+        .. figure:: ../_images/image-close_container-4.png
+
+    Containers of same size:
         If all containers have the same size, no modification is applied.
 
         >>> container1 = abjad.Staff(r"\time 3/4 g'2.")
@@ -89,10 +94,10 @@ def sync_containers(*containers: abjad.Container,
 
         .. figure:: ../_images/image-sync_containers-6.png
 
-    Example:
+    Underfull containers:
         By default, this function closes the longest container by rewriting the
-        time signature of its last bar if necessary (if it is underfull), and
-        uses multi-measure rests whenever possible.
+        time signature of its last measure if necessary (if it is underfull),
+        and uses multi-measure rests whenever possible.
 
         >>> container1 = abjad.Staff(r"\time 4/4 g'1 | f'4")
         >>> container2 = abjad.Staff(r"\time 4/4 c'1")
@@ -119,7 +124,35 @@ def sync_containers(*containers: abjad.Container,
 
         .. figure:: ../_images/image-sync_containers-8.png
 
-    Example:
+    ``adjust_last_time_signature``:
+        To allow containers to be left open (with underfull measures), set the
+        keyword argument ``adjust_last_time_signature`` to ``False``.
+
+        >>> container1 = abjad.Container(r"\time 4/4 g'1 | f'4")
+        >>> container2 = abjad.Container(r"\time 4/4 c'1")
+        >>> auxjad.sync_containers(container1,
+        ...                        container2,
+        ...                        adjust_last_time_signature=False,
+        ...                        )
+        >>> abjad.f(container1)
+        {
+            %%% \time 4/4 %%%
+            g'1
+            f'4
+        }
+
+        .. figure:: ../_images/image-sync_containers-9.png
+
+        >>> abjad.f(container2)
+        {
+            %%% \time 4/4 %%%
+            c'1
+            r4
+        }
+
+        .. figure:: ../_images/image-sync_containers-10.png
+
+    ``use_multimeasure_rests``:
         To disable multi-measure rests, set the keyword argument
         ``use_multimeasure_rests`` to ``False``.
 
@@ -138,7 +171,7 @@ def sync_containers(*containers: abjad.Container,
             f'4
         }
 
-        .. figure:: ../_images/image-sync_containers-9.png
+        .. figure:: ../_images/image-sync_containers-11.png
 
         >>> abjad.f(container2)
         \new Staff
@@ -149,40 +182,12 @@ def sync_containers(*containers: abjad.Container,
             r4
         }
 
-        .. figure:: ../_images/image-sync_containers-10.png
-
-    Example:
-        To allow containers to be left open (with underfull bars), set the
-        keyword argument ``adjust_last_time_signature`` to ``False``.
-
-        >>> container1 = abjad.Container(r"\time 4/4 g'1 | f'4")
-        >>> container2 = abjad.Container(r"\time 4/4 c'1")
-        >>> auxjad.sync_containers(container1,
-        ...                        container2,
-        ...                        adjust_last_time_signature=False,
-        ...                        )
-        >>> abjad.f(container1)
-        {
-            %%% \time 4/4 %%%
-            g'1
-            f'4
-        }
-
-        .. figure:: ../_images/image-sync_containers-11.png
-
-        >>> abjad.f(container2)
-        {
-            %%% \time 4/4 %%%
-            c'1
-            r4
-        }
-
         .. figure:: ../_images/image-sync_containers-12.png
 
-    Example:
+    Adjusting last time signatures:
         When adjusting the last time signature, this function will maintain the
         same time effective signature for as long as possible and only add a
-        new one at the last bar if its duration is shorter.
+        new one at the last measure if its duration is shorter.
 
         >>> container1 = abjad.Staff(r"\time 7/4 a'1 ~ a'2.")
         >>> container2 = abjad.Staff(r"\time 3/4 c'2.")
@@ -199,7 +204,7 @@ def sync_containers(*containers: abjad.Container,
 
         .. figure:: ../_images/image-sync_containers-13.png
 
-    Example:
+    Multiple input containers:
         This function can take an arbitrary number of containers.
 
         >>> container1 = abjad.Staff(r"\time 4/4 c'1 | g'4")
@@ -257,7 +262,58 @@ def sync_containers(*containers: abjad.Container,
 
         .. figure:: ../_images/image-sync_containers-17.png
 
-    Example:
+    Single input |abjad.Score|:
+        This function can also take a single |abjad.Score| instead of
+        multiple |abjad.Container|'s or |abjad.Staff|'s.
+
+        >>> staff1 = abjad.Staff(r"\time 3/8 c'4. | d'4")
+        >>> staff2 = abjad.Staff(r"\time 3/8 c'4. | d'8")
+        >>> staff3 = abjad.Staff(r"\time 3/8 c'4. | d'16")
+        >>> staff4 = abjad.Staff(r"\time 3/8 c'4.")
+        >>> score = abjad.Score([staff1,
+        ...                      staff2,
+        ...                      staff3,
+        ...                      staff4,
+        ...                      ])
+        >>> auxjad.sync_containers(score)
+        >>> abjad.f(score)
+        \new Score
+        <<
+            \new Staff
+            {
+                \time 3/8
+                c'4.
+                \time 1/4
+                d'4
+            }
+            \new Staff
+            {
+                \time 3/8
+                c'4.
+                \time 1/4
+                d'8
+                r8
+            }
+            \new Staff
+            {
+                \time 3/8
+                c'4.
+                \time 1/4
+                d'16
+                r8.
+            }
+            \new Staff
+            {
+                \time 3/8
+                c'4.
+                \time 1/4
+                R1 * 1/4
+            }
+        >>
+
+        .. figure:: ../_images/image-sync_containers-18.png
+
+    Time signature changes:
         The containers can be of different length, can have different time
         signatures, and can contain time signature changes as well.
 
@@ -282,7 +338,7 @@ def sync_containers(*containers: abjad.Container,
             R1*1/4
         }
 
-        .. figure:: ../_images/image-sync_containers-18.png
+        .. figure:: ../_images/image-sync_containers-19.png
 
         >>> abjad.f(container2)
         \new Staff
@@ -294,7 +350,7 @@ def sync_containers(*containers: abjad.Container,
             r4
         }
 
-        .. figure:: ../_images/image-sync_containers-19.png
+        .. figure:: ../_images/image-sync_containers-20.png
 
         >>> abjad.f(container3)
         \new Staff
@@ -305,7 +361,7 @@ def sync_containers(*containers: abjad.Container,
             g''4
         }
 
-        .. figure:: ../_images/image-sync_containers-20.png
+        .. figure:: ../_images/image-sync_containers-21.png
 
         >>> abjad.f(container4)
         \new Staff
@@ -317,8 +373,9 @@ def sync_containers(*containers: abjad.Container,
             R1*1/2
         }
 
-        .. figure:: ../_images/image-sync_containers-21.png
+        .. figure:: ../_images/image-sync_containers-22.png
 
+    Polymetric notation:
         It's important to note that LilyPond does not support simultanoues
         staves with different time signatures (i.e. polymetric notation) by
         default. In order to enable it, the ``"Timing_translator"`` and
@@ -420,29 +477,34 @@ def sync_containers(*containers: abjad.Container,
             }
         } %! abjad.LilyPondFile._get_formatted_blocks()
 
-        .. figure:: ../_images/image-sync_containers-22.png
+        .. figure:: ../_images/image-sync_containers-23.png
 
     ..  error::
 
-        If one or more containers is malformed, i.e. it has an underfilled bar
-        before a time signature change, the function raises a ``ValueError``
-        exception.
+        If one or more containers is malformed, i.e. it has an underfilled
+        measure before a time signature change, the function raises a
+        :exc:`ValueError` exception.
 
         >>> container1 = abjad.Container(r"\time 4/4 g'1 | f'4")
         >>> container2 = abjad.Container(r"\time 5/4 c'1 | \time 4/4 d'4")
         >>> auxjad.sync_containers(container1, container2)
         ValueError: at least one 'container' is malformed, with an underfull
-        bar preceeding a time signature change
+        measure preceeding a time signature change
     """
+    if len(containers) == 1 and isinstance(containers[0], abjad.Score):
+        containers = containers[0][:]
     for container in containers:
         if not isinstance(container, abjad.Container):
             raise TypeError("positional arguments must be 'abjad.Container' "
                             "or child class")
+        if not abjad.select(container).leaves().are_contiguous_logical_voice():
+            raise ValueError("positional arguments must each be contiguous "
+                             "logical voice")
         try:
             container_is_full(container)
         except ValueError as err:
-            raise ValueError("at least one container is malformed, with an "
-                             "underfull bar preceeding a time signature "
+            raise ValueError("at least one 'container' is malformed, with an "
+                             "underfull measure preceeding a time signature "
                              "change") from err
     if not isinstance(use_multimeasure_rests, bool):
         raise TypeError("'use_multimeasure_rests' must be 'bool'")
@@ -455,7 +517,7 @@ def sync_containers(*containers: abjad.Container,
     for container, duration in zip(containers, durations):
         duration_difference = max_duration - duration
         if duration_difference > abjad.Duration(0):
-            # handling duration left in the last bar, if any
+            # handling duration left in the last measure, if any
             if not container_is_full(container):
                 duration_left = underfull_duration(container)
                 underfull_rests_duration = min(duration_difference,
@@ -479,7 +541,7 @@ def sync_containers(*containers: abjad.Container,
                     break
             else:
                 effective_time_signature = abjad.TimeSignature((4, 4))
-            # creating new bars for any leftover duration
+            # creating new measures for any leftover duration
             measure_duration = effective_time_signature.duration
             while duration_difference > measure_duration:
                 rests = abjad.LeafMaker()(None, measure_duration)
